##  Adding Non-SAP-LeanIX Users as Subscribers
You can also add people who are not yet using SAP LeanIX as subscribers. In the Add Person overlay, select + New person and provide the email and name of the person. They will be added to the subscription list, allowing you to contact them through SAP LeanIX. However, they will not receive automatic notifications about fact sheet updates until they are invited to the workspace. You can invite them to the workspace using the + Invite button at any time. Additionally, you can add people to multiple fact sheets in one go. For more information, see [Subscribing and Unsubscribing in Bulk](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a16427a441014be448690c54e7cf0__subscribing_and_unsubscribing_in_bulk).
![Adding Non-SAP-LeanIX Users as Subscribers](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27465ffc7a441014a648a56f0b51deb8_LowRes.png)
Adding Non-SAP-LeanIX Users as Subscribers
